"""Meta-YT: A lightweight Python library for fetching YouTube videos' metadata."""

__title__ = "Meta-YT"
__author__ = "Rystal-Team"
__license__ = "MIT"
__version__ = "0.1.2-beta"

from .caption import Caption
from .video import Video
from .youtube import YouTube
